ComputePipeline

Struct ComputePipeline 

pub struct ComputePipeline {
    pub label: String,
    pub pipeline: Option<ComputePipeline>,
    pub layout: Option<PipelineLayout>,
    pub is_initialized: bool,
    /* private fields */
}
Create a compute pipeline from WGSL source and bind group layouts.

Example

use wde_wgpu::compute_pipeline::ComputePipeline;

let mut pipeline = ComputePipeline::new("particles");
pipeline
    .set_shader(include_str!("../../../res/marching-cubes/spawn_terrain.comp.wgsl"))
    .set_bind_groups(layouts)
    .add_push_constant(16) // bytes starting at offset 0
    .init(instance)
    .expect("shader validated");
assert!(pipeline.is_initialized());

let _wgpu_pipeline = pipeline.get_pipeline().unwrap();

Fields

label: String

Label for the compute pipeline

pipeline: Option<ComputePipeline>

The compute pipeline

layout: Option<PipelineLayout>

The pipeline layout

is_initialized: bool

Whether the compute pipeline has been initialized

Implementations

Source

impl ComputePipeline

pub fn new(label: &str) -> Self

Create a new compute pipeline.

Arguments
  • label - Label of the render pipeline for debugging.
pub fn set_shader(&mut self, shader: &str) -> &mut Self

Set the compute shader of the pipeline.

Arguments
  • shader - The shader source code.
pub fn set_bind_groups(&mut self, layout: Vec<BindGroupLayout>) -> &mut Self

Add a set of bind groups via its layout to the compute pipeline. Note that the order of the bind groups will be the same as the order of the bindings in the shaders.

Arguments
  • layout - The bind group layout.
pub fn add_push_constant(&mut self, offset: u32, size: u32) -> &mut Self

Add a push constant to the compute pipeline.

Arguments
  • offset - The offset of the push constant.
  • size - The size of the push constant.
pub fn init( &mut self, instance: &RenderInstanceData<'_>, ) -> Result<(), RenderError>

Initialize a new compute pipeline.

Arguments
  • instance - Render instance.
Returns
  • Result<(), RenderError> - The result of the initialization.
pub fn get_pipeline(&self) -> Option<&ComputePipeline>

Get the compute pipeline.

Returns
  • Option<&ComputePipelineRef> - The compute pipeline.
pub fn get_layout(&self) -> Option<&PipelineLayout>

Get the pipeline layout.

Returns
  • Option<&PipelineLayout> - The pipeline layout.
pub fn is_initialized(&self) -> bool

Check if the compute pipeline is initialized.

Returns
  • bool - True if the compute pipeline is initialized, false otherwise.