pub struct ComputePipeline {
pub label: String,
pub pipeline: Option<ComputePipeline>,
pub layout: Option<PipelineLayout>,
pub is_initialized: bool,
/* private fields */
}Expand description
Create a compute pipeline from WGSL source and bind group layouts.
Example
use wde_wgpu::compute_pipeline::ComputePipeline;
let mut pipeline = ComputePipeline::new("particles");
pipeline
.set_shader(include_str!("../../../res/marching-cubes/spawn_terrain.comp.wgsl"))
.set_bind_groups(layouts)
.add_push_constant(16) // bytes starting at offset 0
.init(instance)
.expect("shader validated");
assert!(pipeline.is_initialized());
let _wgpu_pipeline = pipeline.get_pipeline().unwrap();Fields
label: StringLabel for the compute pipeline
pipeline: Option<ComputePipeline>The compute pipeline
layout: Option<PipelineLayout>The pipeline layout
is_initialized: boolWhether the compute pipeline has been initialized
Implementations
Sourceimpl ComputePipeline
impl ComputePipeline
Sourcepub fn set_shader(&mut self, shader: &str) -> &mut Self
pub fn set_shader(&mut self, shader: &str) -> &mut Self
Sourcepub fn set_bind_groups(&mut self, layout: Vec<BindGroupLayout>) -> &mut Self
pub fn set_bind_groups(&mut self, layout: Vec<BindGroupLayout>) -> &mut Self
Add a set of bind groups via its layout to the compute pipeline. Note that the order of the bind groups will be the same as the order of the bindings in the shaders.
Arguments
layout- The bind group layout.
Sourcepub fn add_push_constant(&mut self, offset: u32, size: u32) -> &mut Self
pub fn add_push_constant(&mut self, offset: u32, size: u32) -> &mut Self
Add a push constant to the compute pipeline.
Arguments
offset- The offset of the push constant.size- The size of the push constant.
Sourcepub fn init(
&mut self,
instance: &RenderInstanceData<'_>,
) -> Result<(), RenderError>
pub fn init( &mut self, instance: &RenderInstanceData<'_>, ) -> Result<(), RenderError>
Sourcepub fn get_pipeline(&self) -> Option<&ComputePipeline>
pub fn get_pipeline(&self) -> Option<&ComputePipeline>
Sourcepub fn get_layout(&self) -> Option<&PipelineLayout>
pub fn get_layout(&self) -> Option<&PipelineLayout>
Sourcepub fn is_initialized(&self) -> bool
pub fn is_initialized(&self) -> bool
Check if the compute pipeline is initialized.
Returns
bool- True if the compute pipeline is initialized, false otherwise.